/* AlbumCover */
.albumcover-title-label {
    color: @theme_fg_color;
}

.albumcover-artist-label {
    font-size: smaller;
    color: @theme_fg_color;
}

/* By default in Adwaita dark this is not transparent */
.tile {
    background-color: transparent;
}

.playlist-icon {
    padding: 10px;
    border-radius: 50%;
    background-color: alpha(@theme_fg_color, 0.1);
}

.disc-label {
    color: alpha(@theme_fg_color, 0.8);
    padding: 12px 0;
}

/* PlayerToolbar */
.border-solid {
    border-style: solid;
}

.semi-circular {
    border-radius: 20px;
    -gtk-outline-radius: 20px;
}

.semi-circular:hover {
    border-top-width: 0px;
    border-bottom-width: 0px;
    border-left-width: 0px;
    border-right-width: 0px;
}

.pill {
    border-radius: 9999px;
    -gtk-outline-radius: 9999px;
}

.smooth-scale {
    padding-top: 0px;
    padding-bottom: 0px;
}

/* FIXME: Remove once songsview is ported to the new style */
.songs-list-old {
    box-shadow: inset 0 -1px shade(@borders, 1.30);
    background-color: @theme_bg_color;
}

.songs-list-old:selected {
    color: @theme_fg_color;
    border-color: mix(@theme_fg_color, @theme_bg_color, 0.5);
}

/* We use background-image as a workaround on the StarImage widget to
   enable transitions between the non-starred and starred icons. */
.star {
    background-image: -gtk-icontheme('non-starred-symbolic');
    color: alpha(@theme_fg_color, 0.3);
    transition: 100ms linear;
}

.star:hover {
    color: alpha(@theme_fg_color, 0.6);
}

.star:selected {
    background-image: -gtk-icontheme('starred-symbolic');
    color: @theme_selected_bg_color;
    transition: 100ms linear;
}

.content-view { background-color: @theme_bg; }

.grey-image {
    color: alpha(@theme_fg_color, 0.3);
}

/* Used in AlbumWidget and ArtistAlbumsWidget */
.playing-song-label {
    font-weight: bold;
}

/* TwoLineTip */
.tooltip-title {
  font-weight: bold;
}

/* Lists style */

/* workaround to avoid a black background issue
in AlbumWidget and PlaylistsView
https://gitlab.gnome.org/GNOME/gtk/issues/694
*/
list {
    background-color: transparent;
}

.playlistdialog-row:selected {
    color: @theme_fg_color;
    background-color: @theme_insensitive_bg_color;
}

.playlistdialog-row:selected label {
    color: @theme_text_color;
}

/* SearchView */
.search-header {
  font-weight: bold;
}

/* dnd icon for SongWidget */
.drag-handle {
  color: alpha(@theme_fg_color, 0.4);
}

.drag-handle:backdrop {
  color: alpha(@theme_unfocused_fg_color, 0.4);
}

/* Last.fm dialog */
.lastfm-status-label {
    font-weight: bold;
}

/* SongWidget */

.songwidget {
  padding: 12px;
}
